@@ -65,7 +65,10 @@ class ObjectExpirer(Daemon):
             raise ValueError("concurrency must be set to at least 1")
         self.processes = int(self.conf.get('processes', 0))
         self.process = int(self.conf.get('process', 0))
-        self.reclaim_age = int(conf.get('reclaim_age', 86400 * 7))
+        # This option defines how long an un-processable expired object
+        # marker will be retried before it is abandoned.  It is not coupled
+        # with the tombstone reclaim age in the consistency engine.
+        self.reclaim_age = int(conf.get('reclaim_age', 604800))
 
     def report(self, final=False):
         """
@@ -77,15 +80,17 @@ class ObjectExpirer(Daemon):
         """
         if final:
             elapsed = time() - self.report_first_time
-            self.logger.info(_('Pass completed in %ds; %d objects expired') %
-                             (elapsed, self.report_objects))
+            self.logger.info(_('Pass completed in %(time)ds; '
+                               '%(objects)d objects expired') % {
+                             'time': elapsed, 'objects': self.report_objects})
             dump_recon_cache({'object_expiration_pass': elapsed,
                               'expired_last_pass': self.report_objects},
                              self.rcache, self.logger)
         elif time() - self.report_last_time >= self.report_interval:
             elapsed = time() - self.report_first_time
-            self.logger.info(_('Pass so far %ds; %d objects expired') %
-                             (elapsed, self.report_objects))
+            self.logger.info(_('Pass so far %(time)ds; '
+                               '%(objects)d objects expired') % {
+                             'time': elapsed, 'objects': self.report_objects})
             self.report_last_time = time()
 
     def iter_cont_objs_to_expire(self):
@@ -168,8 +173,10 @@ class ObjectExpirer(Daemon):
             self.logger.debug('Run begin')
             containers, objects = \
                 self.swift.get_account_info(self.expiring_objects_account)
-            self.logger.info(_('Pass beginning; %s possible containers; %s '
-                               'possible objects') % (containers, objects))
+            self.logger.info(_('Pass beginning; '
+                               '%(containers)s possible containers; '
+                               '%(objects)s possible objects') % {
+                             'containers': containers, 'objects': objects})
 
             for container, obj in self.iter_cont_objs_to_expire():
                 containers_to_delete.add(container)
@@ -194,8 +201,9 @@ class ObjectExpirer(Daemon):
                         acceptable_statuses=(2, HTTP_NOT_FOUND, HTTP_CONFLICT))
                 except (Exception, Timeout) as err:
                     self.logger.exception(
-                        _('Exception while deleting container %s %s') %
-                        (container, str(err)))
+                        _('Exception while deleting container %(container)s '
+                          '%(err)s') % {'container': container,
+                                        'err': str(err)})
             self.logger.debug('Run end')
             self.report(final=True)
         except (Exception, Timeout):
@@ -247,7 +255,7 @@ class ObjectExpirer(Daemon):
 
         if self.processes and self.process >= self.processes:
             raise ValueError(
-                'process must be less than or equal to processes')
+                'process must be less than processes')
 
     def delete_object(self, actual_obj, timestamp, container, obj):
         start_time = time()
@@ -255,7 +263,8 @@ class ObjectExpirer(Daemon):
             try:
                 self.delete_actual_object(actual_obj, timestamp)
             except UnexpectedResponse as err:
-                if err.resp.status_int != HTTP_NOT_FOUND:
+                if err.resp.status_int not in {HTTP_NOT_FOUND,
+                                               HTTP_PRECONDITION_FAILED}:
                     raise
                 if float(timestamp) > time() - self.reclaim_age:
                     # we'll have to retry the DELETE later
@@ -266,8 +275,9 @@ class ObjectExpirer(Daemon):
         except (Exception, Timeout) as err:
             self.logger.increment('errors')
             self.logger.exception(
-                _('Exception while deleting object %s %s %s') %
-                (container, obj, str(err)))
+                _('Exception while deleting object %(container)s %(obj)s'
+                  ' %(err)s') % {'container': container,
+                                 'obj': obj, 'err': str(err)})
         self.logger.timing_since('timing', start_time)
         self.report()
 
@@ -293,5 +303,6 @@ class ObjectExpirer(Daemon):
         """
         path = '/v1/' + urllib.parse.quote(actual_obj.lstrip('/'))
         self.swift.make_request('DELETE', path,
-                                {'X-If-Delete-At': str(timestamp)},
-                                (2, HTTP_PRECONDITION_FAILED))
+                                {'X-If-Delete-At': str(timestamp),
+                                 'X-Timestamp': str(timestamp)},
+                                (2,))
