@@ -17,14 +17,15 @@
 import hmac
 import hashlib
 import json
-import time
 from copy import deepcopy
 from six.moves import urllib
 from unittest2 import SkipTest
+from time import time, strftime, gmtime
 
 import test.functional as tf
+from swift.common.middleware import tempurl
 from test.functional import cluster_info
-from test.functional.tests import Utils, Base, Base2
+from test.functional.tests import Utils, Base, Base2, BaseEnv
 from test.functional import requires_acls
 from test.functional.swift_test_client import Account, Connection, \
     ResponseError
@@ -38,25 +39,38 @@ def tearDownModule():
     tf.teardown_package()
 
 
-class TestTempurlEnv(object):
+class TestTempurlBaseEnv(BaseEnv):
+    original_account_meta = None
+
+    @classmethod
+    def setUp(cls):
+        super(TestTempurlBaseEnv, cls).setUp()
+        cls.original_account_meta = cls.account.info()
+
+    @classmethod
+    def tearDown(cls):
+        if cls.original_account_meta:
+            # restore any tempurl keys that the tests may have overwritten
+            cls.account.update_metadata(
+                dict((k, cls.original_account_meta.get(k, ''))
+                     for k in ('temp-url-key', 'temp-url-key-2',)))
+
+
+class TestTempurlEnv(TestTempurlBaseEnv):
     tempurl_enabled = None  # tri-state: None initially, then True/False
 
     @classmethod
     def setUp(cls):
-        cls.conn = Connection(tf.config)
-        cls.conn.authenticate()
-
         if cls.tempurl_enabled is None:
             cls.tempurl_enabled = 'tempurl' in cluster_info
             if not cls.tempurl_enabled:
                 return
 
+        super(TestTempurlEnv, cls).setUp()
+
         cls.tempurl_key = Utils.create_name()
         cls.tempurl_key2 = Utils.create_name()
 
-        cls.account = Account(
-            cls.conn, tf.config.get('account', tf.config['username']))
-        cls.account.delete_containers()
         cls.account.update_metadata({
             'temp-url-key': cls.tempurl_key,
             'temp-url-key-2': cls.tempurl_key2
@@ -74,7 +88,6 @@ class TestTempurlEnv(object):
 
 class TestTempurl(Base):
     env = TestTempurlEnv
-    set_up = False
 
     def setUp(self):
         super(TestTempurl, self).setUp()
@@ -86,9 +99,11 @@ class TestTempurl(Base):
                 "Expected tempurl_enabled to be True/False, got %r" %
                 (self.env.tempurl_enabled,))
 
-        expires = int(time.time()) + 86400
+        self.expires = int(time()) + 86400
+        self.expires_8601 = strftime(
+            tempurl.EXPIRES_ISO8601_FORMAT, gmtime(self.expires))
         self.obj_tempurl_parms = self.tempurl_parms(
-            'GET', expires, self.env.conn.make_path(self.env.obj.path),
+            'GET', self.expires, self.env.conn.make_path(self.env.obj.path),
             self.env.tempurl_key)
 
     def tempurl_parms(self, method, expires, path, key):
@@ -99,17 +114,20 @@ class TestTempurl(Base):
         return {'temp_url_sig': sig, 'temp_url_expires': str(expires)}
 
     def test_GET(self):
-        contents = self.env.obj.read(
-            parms=self.obj_tempurl_parms,
-            cfg={'no_auth_token': True})
-        self.assertEqual(contents, "obj contents")
+        for e in (str(self.expires), self.expires_8601):
+            self.obj_tempurl_parms['temp_url_expires'] = e
 
-        # GET tempurls also allow HEAD requests
-        self.assertTrue(self.env.obj.info(parms=self.obj_tempurl_parms,
-                                          cfg={'no_auth_token': True}))
+            contents = self.env.obj.read(
+                parms=self.obj_tempurl_parms,
+                cfg={'no_auth_token': True})
+            self.assertEqual(contents, "obj contents")
+
+            # GET tempurls also allow HEAD requests
+            self.assertTrue(self.env.obj.info(parms=self.obj_tempurl_parms,
+                                              cfg={'no_auth_token': True}))
 
     def test_GET_with_key_2(self):
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         parms = self.tempurl_parms(
             'GET', expires, self.env.conn.make_path(self.env.obj.path),
             self.env.tempurl_key2)
@@ -131,7 +149,7 @@ class TestTempurl(Base):
             hdrs={"X-Object-Manifest": "%s/get-dlo-inside-seg" %
                   (self.env.container.name,)})
 
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         parms = self.tempurl_parms(
             'GET', expires, self.env.conn.make_path(manifest.path),
             self.env.tempurl_key)
@@ -156,7 +174,7 @@ class TestTempurl(Base):
             hdrs={"X-Object-Manifest": "%s/get-dlo-outside-seg" %
                   (self.env.container.name,)})
 
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         parms = self.tempurl_parms(
             'GET', expires, self.env.conn.make_path(manifest.path),
             self.env.tempurl_key)
@@ -169,24 +187,29 @@ class TestTempurl(Base):
     def test_PUT(self):
         new_obj = self.env.container.file(Utils.create_name())
 
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
+        expires_8601 = strftime(
+            tempurl.EXPIRES_ISO8601_FORMAT, gmtime(expires))
+
         put_parms = self.tempurl_parms(
             'PUT', expires, self.env.conn.make_path(new_obj.path),
             self.env.tempurl_key)
+        for e in (str(expires), expires_8601):
+            put_parms['temp_url_expires'] = e
 
-        new_obj.write('new obj contents',
-                      parms=put_parms, cfg={'no_auth_token': True})
-        self.assertEqual(new_obj.read(), "new obj contents")
+            new_obj.write('new obj contents',
+                          parms=put_parms, cfg={'no_auth_token': True})
+            self.assertEqual(new_obj.read(), "new obj contents")
 
-        # PUT tempurls also allow HEAD requests
-        self.assertTrue(new_obj.info(parms=put_parms,
-                                     cfg={'no_auth_token': True}))
+            # PUT tempurls also allow HEAD requests
+            self.assertTrue(new_obj.info(parms=put_parms,
+                                         cfg={'no_auth_token': True}))
 
     def test_PUT_manifest_access(self):
         new_obj = self.env.container.file(Utils.create_name())
 
         # give out a signature which allows a PUT to new_obj
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         put_parms = self.tempurl_parms(
             'PUT', expires, self.env.conn.make_path(new_obj.path),
             self.env.tempurl_key)
@@ -218,7 +241,7 @@ class TestTempurl(Base):
 
         # try again using a tempurl POST to an already created object
         new_obj.write('', {}, parms=put_parms, cfg={'no_auth_token': True})
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         post_parms = self.tempurl_parms(
             'POST', expires, self.env.conn.make_path(new_obj.path),
             self.env.tempurl_key)
@@ -231,24 +254,25 @@ class TestTempurl(Base):
             self.fail('request did not error')
 
     def test_HEAD(self):
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         head_parms = self.tempurl_parms(
             'HEAD', expires, self.env.conn.make_path(self.env.obj.path),
             self.env.tempurl_key)
 
         self.assertTrue(self.env.obj.info(parms=head_parms,
                                           cfg={'no_auth_token': True}))
+
         # HEAD tempurls don't allow PUT or GET requests, despite the fact that
         # PUT and GET tempurls both allow HEAD requests
         self.assertRaises(ResponseError, self.env.other_obj.read,
                           cfg={'no_auth_token': True},
-                          parms=self.obj_tempurl_parms)
+                          parms=head_parms)
         self.assert_status([401])
 
         self.assertRaises(ResponseError, self.env.other_obj.write,
                           'new contents',
                           cfg={'no_auth_token': True},
-                          parms=self.obj_tempurl_parms)
+                          parms=head_parms)
         self.assert_status([401])
 
     def test_different_object(self):
@@ -298,22 +322,6 @@ class TestTempurl(Base):
 
 
 class TestTempURLPrefix(TestTempurl):
-    def setUp(self):
-        super(TestTempurl, self).setUp()
-        if self.env.tempurl_enabled is False:
-            raise SkipTest("TempURL not enabled")
-        elif self.env.tempurl_enabled is not True:
-            # just some sanity checking
-            raise Exception(
-                "Expected tempurl_enabled to be True/False, got %r" %
-                (self.env.tempurl_enabled,))
-
-        self.expires = int(time.time()) + 86400
-        self.obj_tempurl_parms = self.tempurl_parms(
-            'GET', self.expires,
-            self.env.conn.make_path(self.env.obj.path),
-            self.env.tempurl_key)
-
     def tempurl_parms(self, method, expires, path, key,
                       prefix=None):
         path_parts = urllib.parse.unquote(path).split('/')
@@ -376,29 +384,24 @@ class TestTempURLPrefix(TestTempurl):
 
 
 class TestTempurlUTF8(Base2, TestTempurl):
-    set_up = False
+    pass
 
 
-class TestContainerTempurlEnv(object):
+class TestContainerTempurlEnv(BaseEnv):
     tempurl_enabled = None  # tri-state: None initially, then True/False
 
     @classmethod
     def setUp(cls):
-        cls.conn = Connection(tf.config)
-        cls.conn.authenticate()
-
         if cls.tempurl_enabled is None:
             cls.tempurl_enabled = 'tempurl' in cluster_info
             if not cls.tempurl_enabled:
                 return
 
+        super(TestContainerTempurlEnv, cls).setUp()
+
         cls.tempurl_key = Utils.create_name()
         cls.tempurl_key2 = Utils.create_name()
 
-        cls.account = Account(
-            cls.conn, tf.config.get('account', tf.config['username']))
-        cls.account.delete_containers()
-
         # creating another account and connection
         # for ACL tests
         config2 = deepcopy(tf.config)
@@ -426,7 +429,6 @@ class TestContainerTempurlEnv(object):
 
 class TestContainerTempurl(Base):
     env = TestContainerTempurlEnv
-    set_up = False
 
     def setUp(self):
         super(TestContainerTempurl, self).setUp()
@@ -438,7 +440,7 @@ class TestContainerTempurl(Base):
                 "Expected tempurl_enabled to be True/False, got %r" %
                 (self.env.tempurl_enabled,))
 
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         sig = self.tempurl_sig(
             'GET', expires, self.env.conn.make_path(self.env.obj.path),
             self.env.tempurl_key)
@@ -462,7 +464,7 @@ class TestContainerTempurl(Base):
                                           cfg={'no_auth_token': True}))
 
     def test_GET_with_key_2(self):
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         sig = self.tempurl_sig(
             'GET', expires, self.env.conn.make_path(self.env.obj.path),
             self.env.tempurl_key2)
@@ -475,7 +477,7 @@ class TestContainerTempurl(Base):
     def test_PUT(self):
         new_obj = self.env.container.file(Utils.create_name())
 
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         sig = self.tempurl_sig(
             'PUT', expires, self.env.conn.make_path(new_obj.path),
             self.env.tempurl_key)
@@ -491,7 +493,7 @@ class TestContainerTempurl(Base):
                                      cfg={'no_auth_token': True}))
 
     def test_HEAD(self):
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         sig = self.tempurl_sig(
             'HEAD', expires, self.env.conn.make_path(self.env.obj.path),
             self.env.tempurl_key)
@@ -598,7 +600,7 @@ class TestContainerTempurl(Base):
             hdrs={"X-Object-Manifest": "%s/get-dlo-inside-seg" %
                   (self.env.container.name,)})
 
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         sig = self.tempurl_sig(
             'GET', expires, self.env.conn.make_path(manifest.path),
             self.env.tempurl_key)
@@ -624,7 +626,7 @@ class TestContainerTempurl(Base):
             hdrs={"X-Object-Manifest": "%s/get-dlo-outside-seg" %
                   (container2.name,)})
 
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         sig = self.tempurl_sig(
             'GET', expires, self.env.conn.make_path(manifest.path),
             self.env.tempurl_key)
@@ -647,25 +649,20 @@ class TestContainerTempurl(Base):
 
 
 class TestContainerTempurlUTF8(Base2, TestContainerTempurl):
-    set_up = False
+    pass
 
 
-class TestSloTempurlEnv(object):
+class TestSloTempurlEnv(TestTempurlBaseEnv):
     enabled = None  # tri-state: None initially, then True/False
 
     @classmethod
     def setUp(cls):
-        cls.conn = Connection(tf.config)
-        cls.conn.authenticate()
-
+        super(TestSloTempurlEnv, cls).setUp()
         if cls.enabled is None:
             cls.enabled = 'tempurl' in cluster_info and 'slo' in cluster_info
 
         cls.tempurl_key = Utils.create_name()
 
-        cls.account = Account(
-            cls.conn, tf.config.get('account', tf.config['username']))
-        cls.account.delete_containers()
         cls.account.update_metadata({'temp-url-key': cls.tempurl_key})
 
         cls.manifest_container = cls.account.container(Utils.create_name())
@@ -698,7 +695,6 @@ class TestSloTempurlEnv(object):
 
 class TestSloTempurl(Base):
     env = TestSloTempurlEnv
-    set_up = False
 
     def setUp(self):
         super(TestSloTempurl, self).setUp()
@@ -717,7 +713,7 @@ class TestSloTempurl(Base):
             hashlib.sha1).hexdigest()
 
     def test_GET(self):
-        expires = int(time.time()) + 86400
+        expires = int(time()) + 86400
         sig = self.tempurl_sig(
             'GET', expires, self.env.conn.make_path(self.env.manifest.path),
             self.env.tempurl_key)
@@ -734,4 +730,4 @@ class TestSloTempurl(Base):
 
 
 class TestSloTempurlUTF8(Base2, TestSloTempurl):
-    set_up = False
+    pass
