@@ -85,8 +85,8 @@ class TestContainerMergePolicyIndex(ReplProbeTest):
         found_policy_indexes = \
             set(metadata['X-Backend-Storage-Policy-Index'] for
                 node, metadata in head_responses)
-        self.assertTrue(
-            len(found_policy_indexes) > 1,
+        self.assertGreater(
+            len(found_policy_indexes), 1,
             'primary nodes did not disagree about policy index %r' %
             head_responses)
         # find our object
@@ -123,9 +123,9 @@ class TestContainerMergePolicyIndex(ReplProbeTest):
         found_policy_indexes = \
             set(metadata['X-Backend-Storage-Policy-Index'] for
                 node, metadata in head_responses)
-        self.assertTrue(len(found_policy_indexes) == 1,
-                        'primary nodes disagree about policy index %r' %
-                        head_responses)
+        self.assertEqual(len(found_policy_indexes), 1,
+                         'primary nodes disagree about policy index %r' %
+                         head_responses)
 
         expected_policy_index = found_policy_indexes.pop()
         self.assertNotEqual(orig_policy_index, expected_policy_index)
@@ -172,8 +172,8 @@ class TestContainerMergePolicyIndex(ReplProbeTest):
         found_policy_indexes = \
             set(metadata['X-Backend-Storage-Policy-Index'] for
                 node, metadata in head_responses)
-        self.assertTrue(
-            len(found_policy_indexes) > 1,
+        self.assertGreater(
+            len(found_policy_indexes), 1,
             'primary nodes did not disagree about policy index %r' %
             head_responses)
         # find our object
@@ -215,11 +215,11 @@ class TestContainerMergePolicyIndex(ReplProbeTest):
         new_found_policy_indexes = \
             set(metadata['X-Backend-Storage-Policy-Index'] for node,
                 metadata in head_responses)
-        self.assertTrue(len(new_found_policy_indexes) == 1,
-                        'primary nodes disagree about policy index %r' %
-                        dict((node['port'],
-                             metadata['X-Backend-Storage-Policy-Index'])
-                             for node, metadata in head_responses))
+        self.assertEqual(len(new_found_policy_indexes), 1,
+                         'primary nodes disagree about policy index %r' %
+                         dict((node['port'],
+                               metadata['X-Backend-Storage-Policy-Index'])
+                              for node, metadata in head_responses))
         expected_policy_index = new_found_policy_indexes.pop()
         self.assertEqual(orig_policy_index, expected_policy_index)
         # validate object fully deleted
@@ -396,11 +396,11 @@ class TestContainerMergePolicyIndex(ReplProbeTest):
             (node, direct_client.direct_head_container(
                 node, container_part, self.account, self.container_name))
             for node in container_nodes]
-        old_container_node_ids = [
-            node['id'] for node, metadata in head_responses
+        old_container_nodes = [
+            node for node, metadata in head_responses
             if int(old_policy) ==
             int(metadata['X-Backend-Storage-Policy-Index'])]
-        self.assertEqual(2, len(old_container_node_ids))
+        self.assertEqual(2, len(old_container_nodes))
 
         # hopefully memcache still has the new policy cached
         self.brain.put_object(headers={'x-object-meta-test': 'custom-meta'},
@@ -425,7 +425,8 @@ class TestContainerMergePolicyIndex(ReplProbeTest):
         # and get rows enqueued from old nodes
         for server_type in ('container-replicator', 'container-updater'):
             server = Manager([server_type])
-            tuple(server.once(number=n + 1) for n in old_container_node_ids)
+            for node in old_container_nodes:
+                server.once(number=self.config_number(node))
 
         # verify entry in the queue for the "misplaced" new_policy
         for container in int_client.iter_containers('.misplaced_objects'):
