@@ -21,7 +21,7 @@ from contextlib import contextmanager
 
 from test.unit import FakeLogger
 from swift.common.middleware import ratelimit
-from swift.proxy.controllers.base import get_container_memcache_key, \
+from swift.proxy.controllers.base import get_cache_key, \
     headers_to_container_info
 from swift.common.memcached import MemcacheConnectionError
 from swift.common.swob import Request
@@ -169,10 +169,10 @@ class TestRateLimit(unittest.TestCase):
                      'container_ratelimit_75': 30}
         test_ratelimit = ratelimit.filter_factory(conf_dict)(FakeApp())
         test_ratelimit.logger = FakeLogger()
-        self.assertEqual(ratelimit.get_maxrate(
-            test_ratelimit.container_ratelimits, 0), None)
-        self.assertEqual(ratelimit.get_maxrate(
-            test_ratelimit.container_ratelimits, 5), None)
+        self.assertIsNone(ratelimit.get_maxrate(
+            test_ratelimit.container_ratelimits, 0))
+        self.assertIsNone(ratelimit.get_maxrate(
+            test_ratelimit.container_ratelimits, 5))
         self.assertEqual(ratelimit.get_maxrate(
             test_ratelimit.container_ratelimits, 10), 200)
         self.assertEqual(ratelimit.get_maxrate(
@@ -185,7 +185,7 @@ class TestRateLimit(unittest.TestCase):
         conf_dict = {'account_ratelimit': current_rate,
                      'container_ratelimit_3': 200}
         fake_memcache = FakeMemcache()
-        fake_memcache.store[get_container_memcache_key('a', 'c')] = \
+        fake_memcache.store[get_cache_key('a', 'c')] = \
             {'object_count': '5'}
         the_app = ratelimit.filter_factory(conf_dict)(FakeApp())
         the_app.memcache_client = fake_memcache
@@ -229,7 +229,7 @@ class TestRateLimit(unittest.TestCase):
         conf_dict = {'account_ratelimit': current_rate,
                      'container_ratelimit_3': 200}
         fake_memcache = FakeMemcache()
-        fake_memcache.store[get_container_memcache_key('a', 'c')] = \
+        fake_memcache.store[get_cache_key('a', 'c')] = \
             {'container_size': 5}
         the_app = ratelimit.filter_factory(conf_dict)(FakeApp())
         the_app.memcache_client = fake_memcache
@@ -431,8 +431,8 @@ class TestRateLimit(unittest.TestCase):
         req.method = 'PUT'
         req.environ['swift.cache'] = FakeMemcache()
         req.environ['swift.cache'].set(
-            get_container_memcache_key('a', 'c'),
-            {'container_size': 1})
+            get_cache_key('a', 'c'),
+            {'object_count': 1})
 
         time_override = [0, 0, 0, 0, None]
         # simulates 4 requests coming in at same time, then sleeping
@@ -465,8 +465,8 @@ class TestRateLimit(unittest.TestCase):
         req.method = 'GET'
         req.environ['swift.cache'] = FakeMemcache()
         req.environ['swift.cache'].set(
-            get_container_memcache_key('a', 'c'),
-            {'container_size': 1})
+            get_cache_key('a', 'c'),
+            {'object_count': 1})
 
         with mock.patch('swift.common.middleware.ratelimit.get_account_info',
                         lambda *args, **kwargs: {}):
@@ -487,9 +487,8 @@ class TestRateLimit(unittest.TestCase):
             mc = self.test_ratelimit.memcache_client
             try:
                 self.test_ratelimit.memcache_client = None
-                self.assertEqual(
-                    self.test_ratelimit.handle_ratelimit(req, 'n', 'c', None),
-                    None)
+                self.assertIsNone(
+                    self.test_ratelimit.handle_ratelimit(req, 'n', 'c', None))
             finally:
                 self.test_ratelimit.memcache_client = mc
 
